@@ -19,11 +19,11 @@ where
 import Data.FileStore.Types
 import Data.Maybe (fromJust)
 import System.Exit
-import Data.FileStore.Utils (withSanityCheck, hashsMatch, runShellCommand, withVerifyDir, grepSearchRepo) 
+import Data.FileStore.Utils (withSanityCheck, hashsMatch, withVerifyDir, grepSearchRepo, encodeArg)
+import Data.FileStore.MercurialCommandServer
 import Data.ByteString.Lazy.UTF8 (toString)
 import qualified Data.ByteString.Lazy as B
 import qualified Text.ParserCombinators.Parsec as P
-import Codec.Binary.UTF8.String (encodeString)
 import Data.List (nub)
 import Control.Monad (when, liftM, unless)
 import System.FilePath ((</>), splitDirectories, takeFileName)
@@ -50,20 +50,13 @@ mercurialFileStore repo = FileStore {
   , idsMatch          = const hashsMatch repo
   }
 
--- | Run a mercurial command and return error status, error output, standard output.  The repository
--- is used as working directory.
-runMercurialCommand :: FilePath -> String -> [String] -> IO (ExitCode, String, B.ByteString)
-runMercurialCommand repo command args = do
-  (status, err, out) <- runShellCommand repo Nothing "hg" (command : args)
-  return (status, toString err, out)
-
 -- | Initialize a repository, creating the directory if needed.
 mercurialInit :: FilePath -> IO ()
 mercurialInit repo = do
   exists <- doesDirectoryExist repo
   when exists $ withVerifyDir repo $ throwIO RepositoryExists
   createDirectoryIfMissing True repo
-  (status, err, _) <- runMercurialCommand repo "init" []
+  (status, err, _) <- rawRunMercurialCommand repo "init" []
   if status == ExitSuccess
      then
        -- Add a hook so that changes made remotely via hg will be reflected in
@@ -90,7 +83,7 @@ mercurialCommit repo names author logMsg = do
 -- | Save changes (creating file and directory if needed), add, and commit.
 mercurialSave :: Contents a => FilePath -> FilePath -> Author -> Description -> a -> IO ()
 mercurialSave repo name author logMsg contents = do
-  withSanityCheck repo [".hg"] name $ B.writeFile (repo </> encodeString name) $ toByteString contents
+  withSanityCheck repo [".hg"] name $ B.writeFile (repo </> encodeArg name) $ toByteString contents
   (statusAdd, errAdd, _) <- runMercurialCommand repo "add" ["path:" ++ name]
   if statusAdd == ExitSuccess
      then mercurialCommit repo [name] author logMsg
